.. _preprocessor:

Preprocessor
=============================
This module implements the sequential data preprocessing method proposed by Wang et al. (2025).

.. code-block:: python
    
    from pycfrl import preprocessor

.. automodule:: pycfrl.preprocessor
   :members:
   :show-inheritance:
   :special-members: __init__